{ suites, pkgs, ... }:
{
  imports = suites.lap;

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "20.09"; # Did you read the comment?

  boot.loader.efi.canTouchEfiVariables = true;
  hardware.cpu.intel.updateMicrocode = true;

  boot.initrd.availableKernelModules = [ "xhci_pci" "ahci" "usb_storage" "sd_mod" "rtsx_pci_sdmmc" ];
  boot.initrd.kernelModules = [ "dm-snapshot" ];
  boot.kernelModules = [ "kvm-intel" ];
  boot.extraModulePackages = [ ];
  services.fwupd.enable = true;


  fileSystems."/" =
    {
      device = "/dev/disk/by-uuid/75b8df4a-8839-40cd-92ad-dc83007199f4";
      fsType = "btrfs";
    };

  fileSystems."/boot" =
    {
      device = "/dev/disk/by-uuid/B940-3C52";
      fsType = "vfat";
    };

  swapDevices =
    [{ device = "/dev/disk/by-uuid/1b49df34-6db0-487a-9bb1-306ede0245b0"; }];

  boot.kernelParams = [ "intel_pstate=no_hwp" ];
  fileSystems."/".options = [ "noatime" "nodiratime" "discard" ];


  boot.loader.grub = {
    enable = true;
    version = 2;
    device = "nodev";
    efiSupport = true;
    enableCryptodisk = true;
    gfxmodeEfi = "1024x768";
  };
  boot.loader.efi.efiSysMountPoint = "/boot";

  boot.initrd.luks.devices = {
    root = {
      device = "/dev/disk/by-uuid/d51c0e1d-7b44-4011-bb8c-8773df2ca890";
      preLVM = true;
    };
  };

  hardware.opengl.extraPackages = with pkgs; [
    intel-ocl
    intel-compute-runtime
  ];

  networking.networkmanager.enable = true;
}
