{ suites, modulesPath, pkgs, ... }@inputs:
{
  imports = suites.desktop ++ [ (modulesPath + "/installer/scan/not-detected.nix") ];

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "21.05"; # Did you read the comment?


  boot.loader.grub = {
    enable = true;
    version = 2;
    device = "nodev";
    efiSupport = true;
    enableCryptodisk = true;
    gfxmodeEfi = "1024x768";
  };
  boot.loader.efi.efiSysMountPoint = "/boot";

  boot.loader.efi.canTouchEfiVariables = true;

  boot.kernelParams = [ "boot.shell_on_fail=1" "shell_on_fail=1" "shell_on_fail" "boot.shell_on_fail" ];
  networking.hostName = "tesco"; # Define your hostname.
  networking.useDHCP = false;
  networking.interfaces.enp6s0.useDHCP = true;
  networking.networkmanager.enable = true;


  boot.initrd.availableKernelModules = [ "xhci_pci" "ahci" "usbhid" "usb_storage" "sd_mod" "bcache" "nvme" ];

  boot.extraModulePackages = [ ];

  boot.initrd.luks.devices = {
    hdd-root = {
      device = "/dev/disk/by-uuid/ed9e294f-514f-48c1-ad88-1a4b5b65da37";
      preLVM = true;
    };
    ssd-root = {
      device = "/dev/disk/by-uuid/9e30b5f5-9485-45e9-8ee5-129ff17a2562";
      preLVM = true;
      allowDiscards = true;
    };
    m2-root = {
      device = "/dev/disk/by-uuid/9cb8d4e5-f501-48c9-b953-0a2314f207e9";
      preLVM = true;
      allowDiscards = true;
    };
  };

  fileSystems."/" =
    {
      device = "/dev/bcache0";
      fsType = "ext4";
    };

  fileSystems."/boot" =
    {
      device = "/dev/disk/by-label/BOOT";
      fsType = "vfat";
    };

  swapDevices =
    [{ device = "/dev/disk/by-label/ssd-swap"; }];

}
