{ config, lib, pkgs, ... }:
{

  xdg.portal = {
    enable = true;
    wlr.enable = true;
    extraPortals = [
      pkgs.xdg-desktop-portal-kde
    ];
  };

  services.geoclue2.enable = true;
  location.provider = "geoclue2";

  services.redshift = {
    enable = true;
    package = pkgs.gammastep;
    brightness.night = "0.75";
  };

  hardware.opengl = {
    enable = true;
    driSupport = true;
    driSupport32Bit = true;
  };

  services.xserver.enable = true;
  services.xserver.displayManager = {
    lightdm.enable = true;
    defaultSession = "sway";
    autoLogin = { enable = true; user = "mae"; };
  };

  fonts.fonts = with pkgs; [
    noto-fonts
    noto-fonts-cjk
    noto-fonts-emoji
    liberation_ttf
    fira-code
    fira-code-symbols
    dina-font
    proggyfonts
    (nerdfonts.override { fonts = [ "JetBrainsMono" ]; })
  ];

  environment.systemPackages = with pkgs; [
    xdg-desktop-portal-wlr
    brightnessctl
    polkit_gnome
    vulkan-tools
    mesa
  ];

  programs.sway = {
    enable = true;
    wrapperFeatures.gtk = true;
    extraPackages = with pkgs; [

      breeze-gtk
      breeze-qt5
      waybar
      swaylock
      swaybg
      xwayland
      wl-clipboard
      grim
      slurp
      rofi
      rofi-emoji
      mako
      sway-contrib.grimshot
    ];

  };

}
